@@ -27,6 +27,9 @@ requires $PYTHON --version
 # Python tests all fail on macOS because of SIP misfeature.
 requires_not test "$(uname)" = "Darwin"
 
+# Requires libxml2 for h.get_uri
+requires_uri
+
 define script <<'EOF'
 import nbd
 import sys
